TlogEntryBuilder

Struct TlogEntryBuilder 

pub struct TlogEntryBuilder { /* private fields */ }
Helper to create a transparency log entry.

Implementations

Source

impl TlogEntryBuilder

pub fn new() -> Self

Create a new tlog entry builder.

pub fn from_log_entry(entry: &LogEntry, kind: &str, version: &str) -> Self

Create a tlog entry builder from a Rekor LogEntry response.

This method extracts all relevant fields from a Rekor API response and populates the builder automatically.

Arguments
  • entry - The LogEntry returned from the Rekor API
  • kind - The entry kind (e.g., “hashedrekord”, “dsse”)
  • version - The entry version (e.g., “0.0.1”)
pub fn log_index(self, index: u64) -> Self

Set the log index.

pub fn integrated_time(self, time: u64) -> Self

Set the integrated time (Unix timestamp).

pub fn inclusion_promise(self, signed_entry_timestamp: SignedTimestamp) -> Self

Set the inclusion promise (Signed Entry Timestamp).

pub fn inclusion_proof( self, log_index: u64, root_hash: Sha256Hash, tree_size: u64, hashes: Vec<Sha256Hash>, checkpoint: String, ) -> Self

Set the inclusion proof.

Arguments
  • log_index - The log index
  • root_hash - The root hash
  • tree_size - The tree size
  • hashes - The proof hashes
  • checkpoint - The checkpoint envelope
pub fn build(self) -> TransparencyLogEntry

Build the transparency log entry.